tietools.tie_chain_to_tuplet_with_proportions
=============================================

.. autofunction:: abjad.tools.tietools.tie_chain_to_tuplet_with_proportions.tie_chain_to_tuplet_with_proportions
